//********************** sx16.h *****************************
//* This file contains constants for use with Sensoray model
//* 516 DLL.
//* Copyright (C) Sensoray Company 2001
//***********************************************************

#ifndef __SX16__
#define __SX16__

// DLL file name
#define DLLFILENAME "x16.dll"


// System data types and constants
#define SYS_BOARDS  4       // max number of boards supported in the system

// BUFFER structure
typedef struct
  {
  unsigned char *capbuf;    // pointer to capture (uncompressed) buffer
  int capsize;              // size of buffer in bytes
  int width,height;         // picture size in pixels
  } BUFFER;

// Video system constants
#define NTSC    2
#define PAL     1

// Video input type constants
#define CVIDEO  0    // Composite video
#define SVIDEO  1    // S-Video

// Picture sizes
#define SIZE176_1   4
#define SIZE352_1   3
#define SIZE352_2   2
#define SIZE480_2   1
#define SIZE640_2   6
#define SIZE704_2   0
#define SIZE720_2   5


// Error codes
#define ERR_SX_OPEN                     (-1)    //unable to open the driver
#define ERR_DEVICE_NOT_FOUND            (-2)    //no 615 boards found
#define ERR_SELECT_DEVICE               (-3)    //selected board not found
#define ERR_MEM_ALLOC                   (-4)    //memory allocation error
#define ERR_MEM_LOCK                    (-5)    //DMA buffer lock error
#define ERR_I2CINIT_BUSY                (-6)    //internal I2C bus initialization error
#define ERR_I2CINIT_ERR                 (-7)    //internal I2C bus initialization error
#define ERR_TIMEOUT                     (-8)    //internal access timeout
#define ERR_LOADING_DLL                 (-9)    //error loading DLL
#define ERR_FUNCADDR                    (-10)   //error getting a DLL function address
#define ERR_DLL                         (-11)   //error accessing DLL
#define ERR_NO_REGISTERED_DEV           (-12)   //unable to register any boards
#define ERR_I2C                         (-13)   //internal I2C bus error
#define ERR_I2CTO                       (-14)   //internal I2C timeout
#define ERR_DEBI                        (-15)   //internal DEBI bus error
#define ERR_EEPROM                      (-16)   //EEPROM programming error
#define ERR_XPTO                        (-17)   //internal crosspoint switch timeout
#define ERR_SRAM                        (-18)   //error loading SRAM
#define ERR_ILLEGAL_MODE                (-19)   //illegal value in MODE structure
#define ERR_INTERNAL_OBJ                (-20)   //internal oblect allocation error
#define ERR_ACQ_TIMEOUT                 (-21)   //acquisition timeout
#define ERR_INTERRUPT                   (-22)   //interrupt initialization error
#define ERR_THREAD                      (-23)   //error starting interrupt thread
#define ERR_TREAD_EVENT                 (-24)   //error creating thread event
#define ERR_ILLEGAL_INDEX               (-25)   //illegal board index
#define ERR_ENC_LOAD                    (-26)   //encoder load error
#define ERR_DEC_LOAD                    (-27)   //decoder load error
#define ERR_PAR_LOAD                    (-28)   //param load error
#define ERR_MCOD_LOAD                   (-29)   //microcode load error
#define ERR_DATA_ACCESS_TO              (-45)   //internal process data access timeout
#define ERR_DEVICEINFO                  (-46)   //driver error
#define ERR_INT_TO                      (-47)   //interrupt installation timeout

#endif // __SX16__


